## Copyright (C) 2026 The Octave Project Developers
##
## This file is part of Octave.
##
## Octave is free software: you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation, either version 3 of the License, or
## (at your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <https://www.gnu.org/licenses/>.

## -*- texinfo -*-
## @deftypefn {} {@var{result} =} tail (@var{t})
## @deftypefnx {} {@var{result} =} tail (@var{t}, @var{n})
## Preview last @var{n} rows of tall array @var{t}.
##
## If @var{n} is not specified, defaults to 10.
##
## @seealso{tall, head, gather}
## @end deftypefn

function result = tail (t, n = 10)
  if (nargin < 1 || nargin > 2)
    print_usage ();
  endif

  if (strcmp (typeinfo (t), "tall") == 0)
    result = __tail__ (t, n);
  else
    error ("tail: input must be a tall array");
  endif
endfunction

